# OptiSwap

The directory `CryBtoS-OptiSwap` contains the original OptiSwap example smart contract source code
as it was published by the authors of the original OptiSwap paper.

> Eckey, L., Faust, S., & Schlosser, B. OptiSwap: Fast Optimistic Fair Exchange.

The original repository is available at https://github.com/CryBtoS/OptiSwap.
Use kindly permitted by Lisa Eckey (16. April 2020).
